==> openshift-serverless-1-serverless-rhel8-operator-container-1.17.0-5.tar.gz: openshift-serverless-1-serverless-rhel8-operator-container-1.17.0-5/openshift-knative-operator/pkg/monitoring/monitoring_serving.go <==
package monitoring

import (
	"context"

	mf "github.com/manifestival/manifestival"
	"k8s.io/apimachinery/pkg/util/sets"
	"k8s.io/client-go/kubernetes"
	"knative.dev/operator/pkg/apis/operator/v1alpha1"
)

var (
	servingDeployments = sets.NewString("activator", "autoscaler", "autoscaler-hpa", "controller", "domain-mapping", "domainmapping-webhook", "webhook")
)

func ReconcileMonitoringForServing(ctx context.Context, api kubernetes.Interface, ks *v1alpha1.KnativeServing) error {
	return reconcileMonitoring(ctx, api, &ks.Spec.CommonSpec, ks.GetNamespace())
}

func GetServingTransformers(comp v1alpha1.KComponent) []mf.Transformer {
	// When monitoring is off we keep around the required resources, only rbac-proxy is removed
	transformers := []mf.Transformer{injectNamespaceWithSubject(comp.GetNamespace(), OpenshiftMonitoringNamespace)}
	if ShouldEnableMonitoring(comp.GetSpec().GetConfig()) {
		transformers = append(transformers, InjectRbacProxyContainerToDeployments(servingDeployments))
	}
	return transformers
}

func GetServingMonitoringPlatformManifests(ks v1alpha1.KComponent) ([]mf.Manifest, error) {
	rbacManifest, err := getRBACManifest()
	if err != nil {
		return nil, err
	}
	// Serving has one common sa for all pods
	crbM, err := CreateClusterRoleBindingManifest("controller", ks.GetNamespace())
	if err != nil {
		return nil, err
	}
	rbacManifest = rbacManifest.Append(*crbM)
	for c := range servingDeployments {
		if err := AppendManifestsForComponent(c, ks.GetNamespace(), &rbacManifest); err != nil {
			return nil, err
		}
	}
	return []mf.Manifest{rbacManifest}, nil
}

==> openshift-serverless-1-serverless-rhel8-operator-container-1.19.0-1.tar.gz: openshift-serverless-1-serverless-rhel8-operator-container-1.19.0-1/openshift-knative-operator/pkg/monitoring/monitoring_serving.go <==
package monitoring

import (
	"context"

	mf "github.com/manifestival/manifestival"
	"k8s.io/apimachinery/pkg/util/sets"
	"k8s.io/client-go/kubernetes"
	operatorv1alpha1 "knative.dev/operator/pkg/apis/operator/v1alpha1"
)

var (
	servingDeployments = sets.NewString("activator", "autoscaler", "autoscaler-hpa", "controller", "domain-mapping", "domainmapping-webhook", "webhook")
)

func ReconcileMonitoringForServing(ctx context.Context, api kubernetes.Interface, ks *operatorv1alpha1.KnativeServing) error {
	return reconcileMonitoring(ctx, api, &ks.Spec.CommonSpec, ks.GetNamespace())
}

func GetServingTransformers(comp operatorv1alpha1.KComponent) []mf.Transformer {
	// When monitoring is off we keep around the required resources, only rbac-proxy is removed
	transformers := []mf.Transformer{injectNamespaceWithSubject(comp.GetNamespace(), OpenshiftMonitoringNamespace)}
	if ShouldEnableMonitoring(comp.GetSpec().GetConfig()) {
		transformers = append(transformers, InjectRbacProxyContainerToDeployments(servingDeployments))
	}
	return transformers
}

func GetServingMonitoringPlatformManifests(ks operatorv1alpha1.KComponent) ([]mf.Manifest, error) {
	rbacManifest, err := getRBACManifest()
	if err != nil {
		return nil, err
	}
	// Serving has one common sa for all pods
	crbM, err := CreateClusterRoleBindingManifest("controller", ks.GetNamespace())
	if err != nil {
		return nil, err
	}
	rbacManifest = rbacManifest.Append(*crbM)
	for c := range servingDeployments {
		if err := AppendManifestsForComponent(c, ks.GetNamespace(), &rbacManifest); err != nil {
			return nil, err
		}
	}
	return []mf.Manifest{rbacManifest}, nil
}
